@@ -10,7 +10,6 @@ from autoarray.dataset.dataset_model import DatasetModel
 from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
 from autoarray.mask.derive.zoom_2d import Zoom2D
-from autoarray.operators.convolver import Convolver
 from autoarray.operators.over_sampling.over_sampler import OverSampler  # noqa
 from autoarray.inversion.inversion.dataset_interface import DatasetInterface
 from autoarray.inversion.inversion.mapper_valued import MapperValued
@@ -29,6 +28,7 @@ from autoarray.inversion.pixelization.mappers.factory import mapper_from as Mapp
 from autoarray.inversion.pixelization.border_relocator import BorderRelocator
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerNUFFT
+from autoarray.preloads import Preloads
 from autoarray.structures.arrays.uniform_1d import Array1D
 from autoarray.structures.arrays.uniform_2d import Array2D
 from autoarray.structures.arrays.rgb import Array2DRGB
@@ -85,12 +85,12 @@ from autogalaxy import convert
 
 from . import plot
 from . import aggregator as agg
+from .analysis import model_util
 from .lens import subhalo
 from .lens.tracer import Tracer
 from .lens.sensitivity import SubhaloSensitivityResult
 from .lens.to_inversion import TracerToInversion
-from .analysis.positions import PositionsLHResample
-from .analysis.positions import PositionsLHPenalty
+from .analysis.positions import PositionsLH
 from .imaging.simulator import SimulatorImaging
 from .imaging.fit_imaging import FitImaging
 from .imaging.model.analysis import AnalysisImaging
@@ -102,6 +102,7 @@ from .interferometer.model.visualizer import VisualizerInterferometer
 from .point.dataset import PointDataset
 from .point.fit.dataset import FitPointDataset
 from .point.fit.fluxes import FitFluxes
+from .point.fit.times_delays import FitTimeDelays
 from .point.fit.positions.image.abstract import AbstractFitPositionsImagePair
 from .point.fit.positions.image.pair import FitPositionsImagePair
 from .point.fit.positions.image.pair_all import FitPositionsImagePairAll
@@ -113,6 +114,9 @@ from .point.solver import PointSolver
 from .point.solver.shape_solver import ShapeSolver
 from .quantity.fit_quantity import FitQuantity
 from .quantity.model.analysis import AnalysisQuantity
+
+from .analysis.preloads import mapper_indices_from
+
 from . import exc
 from . import mock as m
 from . import util
@@ -126,4 +130,4 @@ from autoconf.fitsable import hdu_list_for_output_from
 
 conf.instance.register(__file__)
 
-__version__ = "2025.5.9.48"
+__version__ = "2025.10.16.1"
