@@ -1,9 +1,9 @@
 import os
 import logging
-from typing import Optional, Union
+from typing import List, Optional
 
 from autoconf import conf
-from autoconf.dictable import to_dict, output_to_json
+from autoconf.dictable import output_to_json
 
 import autofit as af
 import autoarray as aa
@@ -13,8 +13,7 @@ from autogalaxy.analysis.analysis.dataset import AnalysisDataset as AgAnalysisDa
 
 from autolens.analysis.analysis.lens import AnalysisLens
 from autolens.analysis.result import ResultDataset
-from autolens.analysis.positions import PositionsLHResample
-from autolens.analysis.positions import PositionsLHPenalty
+from autolens.analysis.positions import PositionsLH
 
 from autolens import exc
 
@@ -27,14 +26,14 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLens):
     def __init__(
         self,
         dataset,
-        positions_likelihood: Optional[
-            Union[PositionsLHResample, PositionsLHPenalty]
-        ] = None,
+        positions_likelihood_list: Optional[List[PositionsLH]] = None,
         adapt_image_maker: Optional[ag.AdaptImageMaker] = None,
-        cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
+        cosmology: ag.cosmo.LensingCosmology = None,
         settings_inversion: aa.SettingsInversion = None,
+        preloads: aa.Preloads = None,
         raise_inversion_positions_likelihood_exception: bool = True,
         title_prefix: str = None,
+        **kwargs,
     ):
         """
         Fits a lens model to a dataset via a non-linear search.
@@ -49,10 +48,11 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLens):
         ----------
         dataset
             The imaging, interferometer or other dataset that the model if fitted too.
-        positions_likelihood
-            An object which alters the likelihood function to include a term which accounts for whether
-            image-pixel coordinates in arc-seconds corresponding to the multiple images of the lensed source galaxy
-            trace close to one another in the source-plane.
+        positions_likelihood_list
+            Alters the likelihood function to include a term which accounts for whether image-pixel coordinates in
+            arc-seconds corresponding to the multiple images of each lensed source galaxy trace close to one another in
+            their source-plane. This is a list, as it may support multiple planes, where a positions likelihood object
+            is input for each plane (e.g. double source plane lensing).
         adapt_images
             Contains the adapt-images which are used to make a pixelization's mesh and regularization adapt to the
             reconstructed galaxy's morphology.
@@ -62,7 +62,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLens):
             Settings controlling how an inversion is fitted during the model-fit, for example which linear algebra
             formalism is used.
         raise_inversion_positions_likelihood_exception
-            If an inversion is used without the `positions_likelihood` it is likely a systematic solution will
+            If an inversion is used without the `positions_likelihood_list` it is likely a systematic solution will
             be inferred, in which case an Exception is raised before the model-fit begins to inform the user
             of this. This exception is not raised if this input is False, allowing the user to perform the model-fit
             anyway.
@@ -73,12 +73,14 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLens):
             adapt_image_maker=adapt_image_maker,
             cosmology=cosmology,
             settings_inversion=settings_inversion,
+            preloads=preloads,
             title_prefix=title_prefix,
+            **kwargs,
         )
 
         AnalysisLens.__init__(
             self=self,
-            positions_likelihood=positions_likelihood,
+            positions_likelihood_list=positions_likelihood_list,
             cosmology=cosmology,
         )
 
@@ -124,7 +126,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLens):
 
         if has_pix:
             if (
-                self.positions_likelihood is None
+                self.positions_likelihood_list is None
                 and self.raise_inversion_positions_likelihood_exception
                 and not conf.instance["general"]["test"][
                     "disable_positions_lh_inversion_check"
@@ -133,7 +135,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLens):
                 raise exc.AnalysisException(
                     """
                     You have begun a model-fit which reconstructs the source using a pixelization.
-                    However, you have not input a `positions_likelihood` object.
+                    However, you have not input a `positions_likelihood_list` object.
                     It is likely your model-fit will infer an inaccurate solution.
                     
                     Please read the following readthedocs page for a description of why this is, and how to set up
