@@ -1,5 +1,6 @@
 import ast
 import numpy as np
+from typing import Optional
 
 from autoconf import conf
 from autoconf.fitsable import hdu_list_for_output_from
@@ -31,7 +32,12 @@ class PlotterInterface(AgPlotterInterface):
         The path on the hard-disk to the `image` folder of the non-linear searches results.
     """
 
-    def tracer(self, tracer: Tracer, grid: aa.type.Grid2DLike):
+    def tracer(
+        self,
+        tracer: Tracer,
+        grid: aa.type.Grid2DLike,
+        visuals_2d_of_planes_list: Optional[aplt.Visuals2D] = None,
+    ):
         """
         Visualizes a `Tracer` object.
 
@@ -63,7 +69,7 @@ class PlotterInterface(AgPlotterInterface):
             tracer=tracer,
             grid=grid,
             mat_plot_2d=mat_plot_2d,
-            include_2d=self.include_2d,
+            visuals_2d_of_planes_list=visuals_2d_of_planes_list,
         )
 
         if should_plot("subplot_galaxies_images"):
@@ -139,7 +145,7 @@ class PlotterInterface(AgPlotterInterface):
 
     def image_with_positions(self, image: aa.Array2D, positions: aa.Grid2DIrregular):
         """
-        Visualizes the positions of a model-fit, where these positions are used to resample lens models where
+        Visualizes the positions of a model-fit, where these positions are used to penalize lens models where
         the positions to do trace within an input threshold of one another in the source-plane.
 
         Images are output to the `image` folder of the `image_path`. When used with a non-linear search the `image_path`
@@ -154,8 +160,8 @@ class PlotterInterface(AgPlotterInterface):
         ----------
         imaging
             The imaging dataset whose image the positions are overlaid.
-        position
-            The 2D (y,x) arc-second positions used to resample inaccurate mass models.
+        positions
+            The 2D (y,x) arc-second positions used to penalize inaccurate mass models.
         """
 
         def should_plot(name):
@@ -169,7 +175,6 @@ class PlotterInterface(AgPlotterInterface):
             image_plotter = aplt.Array2DPlotter(
                 array=image,
                 mat_plot_2d=mat_plot_2d,
-                include_2d=self.include_2d,
                 visuals_2d=visuals_2d,
             )
 
