@@ -1,8 +1,10 @@
 import autofit as af
+import autogalaxy as ag
 
 from autolens.interferometer.model.plotter_interface import (
     PlotterInterfaceInterferometer,
 )
+from autolens.lens import tracer_util
 from autogalaxy import exc
 
 
@@ -34,10 +36,17 @@ class VisualizerInterferometer(af.Visualizer):
 
         plotter_interface.interferometer(dataset=analysis.interferometer)
 
-        if analysis.positions_likelihood is not None:
+        if analysis.positions_likelihood_list is not None:
+
+            positions_list = []
+
+            for positions_likelihood in analysis.positions_likelihood_list:
+                positions_list.append(positions_likelihood.positions)
+
+            positions = ag.Grid2DIrregular(positions_list)
+
             plotter_interface.image_with_positions(
-                image=analysis.dataset.dirty_image,
-                positions=analysis.positions_likelihood.positions,
+                image=analysis.dataset.dirty_image, positions=positions
             )
 
         if analysis.adapt_images is not None:
@@ -81,10 +90,19 @@ class VisualizerInterferometer(af.Visualizer):
         """
         fit = analysis.fit_from(instance=instance)
 
-        if analysis.positions_likelihood is not None:
-            analysis.positions_likelihood.output_positions_info(
-                output_path=paths.output_path, tracer=fit.tracer
-            )
+        if analysis.positions_likelihood_list is not None:
+
+            overwrite_file = True
+
+            for positions_likelihood in analysis.positions_likelihood_list:
+
+                positions_likelihood.output_positions_info(
+                    output_path=paths.output_path,
+                    tracer=fit.tracer,
+                    overwrite_file=overwrite_file,
+                )
+
+                overwrite_file = False
 
         if fit.inversion is not None:
             try:
@@ -92,22 +110,34 @@ class VisualizerInterferometer(af.Visualizer):
             except exc.InversionException:
                 return
 
+        visuals_2d_of_planes_list = tracer_util.visuals_2d_of_planes_list_from(
+            tracer=fit.tracer, grid=fit.grids.lp.mask.derive_grid.all_false
+        )
+
+        tracer = fit.tracer_linear_light_profiles_to_light_profiles
+
+        zoom = ag.Zoom2D(mask=fit.dataset.real_space_mask)
+
+        extent = zoom.extent_from(buffer=0)
+        shape_native = zoom.shape_native
+
+        grid = ag.Grid2D.from_extent(extent=extent, shape_native=shape_native)
+
         plotter_interface = PlotterInterfaceInterferometer(
             image_path=paths.image_path, title_prefix=analysis.title_prefix
         )
 
         try:
             plotter_interface.fit_interferometer(
-                fit=fit,
+                fit=fit, visuals_2d_of_planes_list=visuals_2d_of_planes_list
             )
         except exc.InversionException:
             pass
 
-        tracer = fit.tracer_linear_light_profiles_to_light_profiles
-
         plotter_interface.tracer(
             tracer=tracer,
-            grid=fit.grids.lp,
+            grid=grid,
+            visuals_2d_of_planes_list=visuals_2d_of_planes_list,
         )
         plotter_interface.galaxies(
             galaxies=tracer.galaxies,
