@@ -17,7 +17,7 @@ class TracerToInversion(ag.AbstractToInversion):
         tracer,
         adapt_images: Optional[ag.AdaptImages] = None,
         settings_inversion: aa.SettingsInversion = aa.SettingsInversion(),
-        run_time_dict: Optional[Dict] = None,
+        preloads: aa.Preloads = None,
     ):
         """
         Interfaces a dataset and tracer with the inversion module, to setup a linear algebra calculation.
@@ -52,16 +52,14 @@ class TracerToInversion(ag.AbstractToInversion):
             the pixelization's pixels to the brightest regions of the image.
         settings_inversion
             The settings of the inversion, which controls how the linear algebra calculation is performed.
-        run_time_dict
-            A dictionary of run-time values used to compute the inversion, for example the noise-map normalization.
         """
         self.tracer = tracer
+        self.preloads = preloads
 
         super().__init__(
             dataset=dataset,
             adapt_images=adapt_images,
             settings_inversion=settings_inversion,
-            run_time_dict=run_time_dict,
         )
 
     @property
@@ -99,7 +97,6 @@ class TracerToInversion(ag.AbstractToInversion):
                 return True
 
     @cached_property
-    @aa.profile_func
     def traced_grid_2d_list_of_inversion(self) -> List[aa.type.Grid2DLike]:
         """
         Returns a list of the traced grids of the inversion.
@@ -176,13 +173,18 @@ class TracerToInversion(ag.AbstractToInversion):
                 blurring=traced_blurring_grids_of_planes_list[plane_index],
             )
 
+            if self.settings_inversion.use_w_tilde:
+                w_tilde = self.dataset.w_tilde
+            else:
+                w_tilde = None
+
             dataset = aa.DatasetInterface(
                 data=self.dataset.data,
                 noise_map=self.dataset.noise_map,
                 grids=grids,
-                convolver=self.convolver,
+                psf=self.psf,
                 transformer=self.transformer,
-                w_tilde=self.dataset.w_tilde,
+                w_tilde=w_tilde,
             )
 
             galaxies_to_inversion = ag.GalaxiesToInversion(
@@ -190,7 +192,6 @@ class TracerToInversion(ag.AbstractToInversion):
                 galaxies=galaxies,
                 settings_inversion=self.settings_inversion,
                 adapt_images=self.adapt_images,
-                run_time_dict=self.run_time_dict,
             )
 
             lp_linear_galaxy_dict_of_plane = (
@@ -284,7 +285,6 @@ class TracerToInversion(ag.AbstractToInversion):
         return adapt_galaxy_image_pg_list
 
     @cached_property
-    @aa.profile_func
     def image_plane_mesh_grid_pg_list(self) -> List[List]:
         """
         Returns a list of lists of image-plane mesh grids, where each inner list corresponds to a single plane.
@@ -315,7 +315,6 @@ class TracerToInversion(ag.AbstractToInversion):
                 galaxies=galaxies,
                 adapt_images=self.adapt_images,
                 settings_inversion=self.settings_inversion,
-                run_time_dict=self.run_time_dict,
             )
 
             image_plane_mesh_grid_list = to_inversion.image_plane_mesh_grid_list
@@ -324,7 +323,6 @@ class TracerToInversion(ag.AbstractToInversion):
         return image_plane_mesh_grid_list_of_planes
 
     @cached_property
-    @aa.profile_func
     def traced_mesh_grid_pg_list(self) -> List[List]:
         """
         Returns a list of lists of traced mesh grids, where each inner list corresponds to a single plane.
@@ -412,7 +410,6 @@ class TracerToInversion(ag.AbstractToInversion):
                     galaxies=galaxies,
                     adapt_images=self.adapt_images,
                     settings_inversion=self.settings_inversion,
-                    run_time_dict=self.run_time_dict,
                 )
 
                 galaxies_with_pixelization_list = galaxies.galaxies_with_cls_list_from(
@@ -476,7 +473,7 @@ class TracerToInversion(ag.AbstractToInversion):
             dataset=self.dataset,
             linear_obj_list=self.linear_obj_list,
             settings=self.settings_inversion,
-            run_time_dict=self.tracer.run_time_dict,
+            preloads=self.preloads,
         )
 
         inversion.linear_obj_galaxy_dict = self.linear_obj_galaxy_dict
